mailr23608 - /trunk/gui/input_elements/file.py


Others Months | Index by Date | Thread Index
>>   [Date Prev] [Date Next] [Thread Prev] [Thread Next]

Header


Content

Posted by edward on May 30, 2014 - 10:11:
Author: bugman
Date: Fri May 30 10:11:09 2014
New Revision: 23608

URL: http://svn.gna.org/viewcvs/relax?rev=23608&view=rev
Log:
Another fix for bug #22112 (http://gna.org/bugs/?22112).

This is the GUI failure when setting list values via the sequence windows, 
launched from user
function windows fails on Mac OS X.  This change is for the multiple file 
selection window and
matches the previous change by replacing the Mac OS X fatal 
wx.Dialog.Destroy() call with
wx.Dialog.Close().


Modified:
    trunk/gui/input_elements/file.py

Modified: trunk/gui/input_elements/file.py
URL: 
http://svn.gna.org/viewcvs/relax/trunk/gui/input_elements/file.py?rev=23608&r1=23607&r2=23608&view=diff
==============================================================================
--- trunk/gui/input_elements/file.py    (original)
+++ trunk/gui/input_elements/file.py    Fri May 30 10:11:09 2014
@@ -824,8 +824,8 @@
         @type event:    wx event
         """
 
-        # Destroy the window.
-        self.Destroy()
+        # Close the window.
+        self.Close()
 
 
     def delete(self, event=None):




Related Messages


Powered by MHonArc, Updated Fri May 30 10:20:03 2014